@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.110-9-gbf3609a
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.111-3-gb7e4ea1
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
-# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.111';
+our $VERSION = '0.112';
 
 use Moose;
 with
@@ -233,7 +233,7 @@ sub configure
         [ 'Test::Pod::No404s'   => { ':version' => '1.002' } ],
         [ 'Test::Kwalitee'      => { ':version' => '2.10', filename => 'xt/author/kwalitee.t' } ],
         [ 'MojibakeTests'       => { ':version' => '0.8' } ],
-        [ 'Test::ReportPrereqs' => { ':version' => '0.019', verify_prereqs => 1,
+        [ 'Test::ReportPrereqs' => { ':version' => '0.022', verify_prereqs => 1, version_extractor => 'Module::Metadata',
             exists $removed{PodCoverageTests} ? () : ( include => [ 'Pod::Coverage' ] ),
           } ],
         'Test::Portability',
@@ -454,7 +454,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.111
+version 0.112
 
 =head1 SYNOPSIS
 
@@ -576,8 +576,9 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [MojibakeTests]
     :version = 0.8
     [Test::ReportPrereqs]
-    :version = 0.019
+    :version = 0.022
     verify_prereqs = 1
+    version_extractor = Module::Metadata
     include = Pod::Coverage
     [Test::Portability]
     [Test::CleanNamespaces]
